==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AAbstractModifier.h <==
// public final class soot.jimple.parser.node.AAbstractModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a060e16d335dd4f9 soot_jimple_parser_node_AAbstractModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AAbstractModifier_H_
#define _JC_soot_jimple_parser_node_AAbstractModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TAbstract$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs	_jc_soot_jimple_parser_node_AAbstractModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$refs	_jc_soot_jimple_parser_node_AAbstractModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$nonrefs	_jc_soot_jimple_parser_node_AAbstractModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$object	_jc_soot_jimple_parser_node_AAbstractModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vmethods	_jc_soot_jimple_parser_node_AAbstractModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vtable	_jc_soot_jimple_parser_node_AAbstractModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vtype	_jc_soot_jimple_parser_node_AAbstractModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$_init$687a3c8c3160a90a(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
extern struct _jc_soot_jimple_parser_node_TAbstract$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$getAbstract$d65aa4d35fe54bcb(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$setAbstract$cd06c1bbf223f0a0(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$getAbstract$d65aa4d35fe54bcb;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$setAbstract$cd06c1bbf223f0a0;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AAbstractModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
	struct _jc_soot_jimple_parser_node_TAbstract$object	*(*getAbstract$d65aa4d35fe54bcb)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setAbstract$cd06c1bbf223f0a0)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AAbstractModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AAbstractModifier$vmethods	soot_jimple_parser_node_AAbstractModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AAbstractModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AAbstractModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TAbstract$object	*__5fabstract__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAbstractModifier$refs {
    _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs	soot_jimple_parser_node_AAbstractModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAbstractModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs	soot_jimple_parser_node_AAbstractModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AAbstractModifier$object {
	_jc_soot_jimple_parser_node_AAbstractModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AAbstractModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AAbstractModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AAbstractModifier$vtype _jc_soot_jimple_parser_node_AAbstractModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AAbstractModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AAbstractModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AAbstractModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AAbstractModifier.h <==
// public final class soot.jimple.parser.node.AAbstractModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a060e16d335dd4f9 soot_jimple_parser_node_AAbstractModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AAbstractModifier_H_
#define _JC_soot_jimple_parser_node_AAbstractModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TAbstract$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs	_jc_soot_jimple_parser_node_AAbstractModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$refs	_jc_soot_jimple_parser_node_AAbstractModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$nonrefs	_jc_soot_jimple_parser_node_AAbstractModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAbstractModifier$object	_jc_soot_jimple_parser_node_AAbstractModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vmethods	_jc_soot_jimple_parser_node_AAbstractModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vtable	_jc_soot_jimple_parser_node_AAbstractModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AAbstractModifier$vtype	_jc_soot_jimple_parser_node_AAbstractModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$_init$687a3c8c3160a90a(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TAbstract$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$getAbstract$d65aa4d35fe54bcb(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAbstractModifier$method$setAbstract$cd06c1bbf223f0a0(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AAbstractModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$getAbstract$d65aa4d35fe54bcb;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$setAbstract$cd06c1bbf223f0a0;
extern _jc_method _jc_soot_jimple_parser_node_AAbstractModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AAbstractModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TAbstract$object	*(*getAbstract$d65aa4d35fe54bcb)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setAbstract$cd06c1bbf223f0a0)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *, struct _jc_soot_jimple_parser_node_TAbstract$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AAbstractModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AAbstractModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AAbstractModifier$vmethods	soot_jimple_parser_node_AAbstractModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AAbstractModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AAbstractModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TAbstract$object	*__5fabstract__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAbstractModifier$refs {
    _jc_soot_jimple_parser_node_AAbstractModifier$sub_refs	soot_jimple_parser_node_AAbstractModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAbstractModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AAbstractModifier$sub_nonrefs	soot_jimple_parser_node_AAbstractModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AAbstractModifier$object {
	_jc_soot_jimple_parser_node_AAbstractModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AAbstractModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AAbstractModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AAbstractModifier$vtype _jc_soot_jimple_parser_node_AAbstractModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AAbstractModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AAbstractModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AAbstractModifier_H_ */
